<?php

require_once 'backend/error_reporting_config.php';

session_start();
define("OVS", true); // Im a simple security man. I only want requires to be called by me.
require_once 'backend/helpers.php';

$login = false;

if(isset($_SESSION['login']) && $_SESSION['login'] === 1) {
    
    $ip = getUserIP();
    if($_SESSION['ip'] != $ip) {
        
        header('Location: logout.php?error=ipc');
        exit;
    }
    $login = true;
}

if(!$login) {
    
    header('Location: index.php');
    exit;
}

$params = @$_SESSION['info'];

$name = $params['name'];
$surname = $params['surname'];
$by = $params['by'];
$ni = $params['ni'];

// Database connection is established here for better performance
require_once 'backend/connect.php';

// Last check before adding vote to database
$stmt = $pdo->prepare("SELECT voted_at FROM votedpersons WHERE id = :id");
$stmt->bindParam(':id', $ni, PDO::PARAM_STR);
$stmt->execute();
if($stmt->rowCount() > 0) {
    
    unset($stmt);
    unset($pdo);
    header('Location: index.php?error=alreadyvoted');
    exit;
}

$token = sha1(base64_encode(md5($nm . ' ' . $sm . ' ' . $cc . ' ' . $cc . ' ' . base64_encode($cc) . strrev($sm . ' ' . $nm)))); // Generate user token from summary of user's information

if(isset($_COOKIE['acm368_OVS']) && !empty($_COOKIE['acm368_OVS'])) {
    
    $tokenval = $_COOKIE['acm368_OVS'];
    if($tokenval != $token) {
        
        // Kill the session if voted before
        $_SESSION = [];
        session_destroy();
        
        header('Location: index.php?error=message&msg=' . urlencode("You voted from this device before!"));
        exit;
    }
}

// Someone is voting for a candidate
if($_SERVER['REQUEST_METHOD'] == 'POST') {
    
    if(isset($_POST['candidate']) && !empty($_POST['candidate']) && $_POST['candidate'] != '0' && is_numeric(trim($_POST['candidate']))) {
        
        $candidate = trim($_POST['candidate']);
        $stmt = $pdo->prepare('INSERT into votedpersons (id, votedfor) VALUES (:id, :votedfor)');
        $stmt->bindParam(':id', $ni, PDO::PARAM_STR);
        $stmt->bindParam(':votedfor', $candidate, PDO::PARAM_STR);
        $stmt->execute();
        
        // Kill the session after voting is done
        $_SESSION = [];
        session_destroy();
        
        unset($stmt);
        unset($pdo);
        header('Location: voteresults.php');
        exit;
    }
}

// Get the candidates
$stmt = $pdo->prepare("SELECT * FROM voteoptions");
$stmt->execute();
$candidates = $stmt->fetchAll();
unset($stmt);
unset($pdo);

?>
<!DOCTYPE html>
<html>
  <head>
    <title>Voting System</title>
    <link href="https://fonts.googleapis.com/css?family=Roboto:300,400,500,700" rel="stylesheet">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <style>
      html, body {
      display: flex;
      justify-content: center;
      font-family: Roboto, Arial, sans-serif;
      font-size: 15px;
      }
      form {
      border: 5px solid #f1f1f1;
      }
      input[type=text], input[type=password] {
      width: 100%;
      padding: 16px 8px;
      margin: 8px 0;
      display: inline-block;
      border: 1px solid #ccc;
      box-sizing: border-box;
      }
      button {
      background-color: #8ebf42;
      color: white;
      padding: 14px 0;
      margin: 10px 0;
      border: none;
      cursor: grabbing;
      width: 100%;
      }
      h1 {
      text-align:center;
      fone-size:18;
      }
      button:hover {
      opacity: 0.8;
      }
      .formcontainer {
      text-align: left;
      margin: 24px 50px 12px;
      }
      .container {
      padding: 16px 0;
      text-align:left;
      }
      span.psw {
      float: right;
      padding-top: 0;
      padding-right: 15px;
      }
      /* Change styles for span on extra small screens */
      @media screen and (max-width: 300px) {
      span.psw {
      display: block;
      float: none;
      }
    </style>
  </head>
  <body>
    <form method="post">
      <h1>Voting System</h1>
      <div class="formcontainer">
      <hr/>
      <h4>Welcome to (OVS) voting system <?=$name . ' ' . $surname;?></h4>
      <p>Keep in mind, you can only vote once!</p>
      <button><a href="logout.php">Click here to log out and vote later</a></button>
      <div class="container">
        <label for="candidates">Vote for a candidate:</label>
        <select name="candidate" id="candidates">
            <?php
                
                if(empty($candidates)) {
                    
                    ?>
                    <option value="0">NO CANDIDATE FOUND!</option>
                    <?php
                }else{
                
                    foreach($candidates as $candidate) {
                    
                        ?>
                    
                    <option value="<?=$candidate['id'];?>"><?=$candidate['name'];?></option>
                    
                    <?php
                    }
                }
            ?>
        </select>
      </div>
      <button type="submit">Vote</button>
    </form>
  </body>
</html>